/**
 * Created by 谭兵 on 2016/12/2.
 */
//全局公共函数
window.Common = {
    isEmpty: function (val) {
        if (val == undefined || val == null || val == "") {
            return true;
        }
        return false;
    },

    /**
     * 取得cookie
     * @param name 键名
     * @returns {string} 如果没有值返回null
     */
    getCookie: function (name) {
        if (typeof ($api) != "undefined") {
            try {
                return $api.getStorage(name);
            } catch (e) {
                return null;
            }
        } else {
            var nameEQ = name + "=";
            var ca = document.cookie.split(';');    //把cookie分割成组
            for (var i = 0; i < ca.length; i++) {
                var c = ca[i];                      //取得字符串
                while (c.charAt(0) == ' ') {          //判断一下字符串有没有前导空格
                    c = c.substring(1, c.length);      //有的话，从第二位开始取
                }
                if (c.indexOf(nameEQ) == 0) {       //如果含有我们要的name
                    return unescape(c.substring(nameEQ.length, c.length));    //解码并截取我们要值
                }
            }
            return null;
        }
    },

    /**
     * 清除cookie
     * @param name 键名
     */
    clearCookie: function (name) {
        if (typeof($api) != "undefined") {
            $api.rmStorage(name);
        } else {
            this.setCookie(name, "", -1);
        }
    },

    /**
     * 设置cookie
     * @param name 键
     * @param value  值
     * @param seconds  保存时间，单位（秒）
     */
    setCookie: function (name, value, seconds) {
        if (typeof($api) != "undefined") {
            $api.setStorage(name, value);
        } else {
            seconds = seconds || 0;   //seconds有值就直接赋值，没有为0
            var expires = "";
            if (seconds != 0) {      //设置cookie生存时间
                var date = new Date();
                date.setTime(date.getTime() + (seconds * 1000));
                expires = "; expires=" + date.toGMTString();
            }
            document.cookie = name + "=" + escape(value) + expires + "; path=/";   //转码并赋值
        }
    },

    /**
     * 显示元素 设置hidden
     * @param el
     */
    show: function (el) {
        el.removeAttribute("hidden");
    },

    /**
     * 隐藏元素
     * @param el
     */
    hide: function (el) {
        el.setAttribute("hidden", '');
    },

    showDisplay: function (el) {
        el.style.display = "block";
    },

    hideDisplay: function (el) {
        el.style.display = "none";
    },

    /**
     * 检查input的长度
     * @param {elements} el   input对象
     * @param {number} number  长度
     */
    checkInputLength : function (el, num) {
        if(el.value.length > num){
            el.value = el.value.substring(0, num+1);
        }
    },

    /**
     * 验证字符串是否只包含英文字母和汉字
     * @param {string}val 要验证的字符串
     * @return {boolean} true正确，反之不正确
     */
    checkZHAndEN: function (val) {
        if (/[^\u4E00-\u9FA5a-zA-Z\s]/g.test(val)) {
            return false;
        }
        return true;
    },
    /**
     * 验证字符串是否只包含汉字
     * @param {string}val 要验证的字符串
     * @returns {boolean}
     */
    checkZh: function (val) {
        if (/[^\u4E00-\u9FA5]/g.test(val)) {
            return false;
        }
        return true;
    },
    /**
     * 验证手机号是否正确 11位 不加86
     * @param {string}phone 待验证的手机号
     * @returns {boolean} true正确，反之不正确
     */
    checkPhone: function (phone) {
        if (!(/^1[34578]\d{9}$/.test(phone))) {
            return false;
        }
        return true;
    },
    /**
     * 去掉首尾空格
     * @param {string}str
     * @returns {string}
     */
    trim: function (str) {
        return str.replace(/(^\s*)|(\s*$)/g, "");
    }
};

//封装了所有弹框
window.TDialog = {
    base: function () {
        return {
            baseEl: document.getElementById("dialog-hint"),
            isShow: false,
            baseUpdate: function () {
                this.baseEl = document.getElementById("dialog-hint");
            },
            /**
             * 显示弹框
             */
            show: function () {
                if(!this.isShow){
                    this.baseEl.removeAttribute("hidden");
                    this.isShow = true;
                }

            },
            /**
             * 隐藏弹框
             */
            hide: function () {
                if(this.isShow){
                    this.baseEl.setAttribute("hidden", "");
                    this.isShow = false;
                }
            }
        };
    },

    /**
     * 下面是弹框html代码片段，html中必需包含下面代码，不然此对象将无法使用
     * <code><div id="dialog-hint" class="dialog-wrap tc" onclick="this.setAttribute('hidden', '');" hidden>
     * &nbsp;&nbsp;<div class="hint-dialog" onclick="event.stopPropagation();">
     * &nbsp;&nbsp;&nbsp;&nbsp;&lt;p id="hint-text" class="dialog-hint-text tl">这是弹框提示信息&lt;/p&gt
     * &nbsp;&nbsp;&nbsp;&nbsp;&lt;p class="hint-left-but">左按钮&lt;/p&gt;&lt;p class="hint-right-but">右按钮&lt;/p&gt;
     * &nbsp;&nbsp;</div>
     * </div></code>
     * 提示弹框，带两个按钮，左边和右边
     * @param text   提示文本
     * @param leftListener  左边按钮点击事件
     * @param rightListener 右边按钮点击事件
     * @returns {*|{baseEl, update}} 返回此对象，可以创建多个此对象
     */
    hintDialog : function (text, leftListener, rightListener) {
        var obj = this.base();
        obj.leftListener = leftListener;
        obj.rightListener = rightListener;
        obj.text = text;
        //更新
        obj.update = function () {
            obj.baseUpdate();
            obj.leftEl = obj.baseEl.querySelector(".hint-left-but");
            obj.rightEl = obj.baseEl.querySelector(".hint-right-but");
            obj.textEl = obj.baseEl.querySelector(".dialog-hint-text");
            obj.textEl.innerHTML = obj.text;
            obj.leftEl.addEventListener("click", function () {
                obj.leftListener();
            });
            obj.rightEl.addEventListener("click", function () {
                obj.rightListener();
            });
        };
        /**
         * 更新提示文本
         */
        obj.updateText = function () {
            obj.textEl.innerHTML = obj.text;
        };
        /**
         * 设置提示文本
         * @param text 要设置的文本
         */
        obj.setText = function (text) {
            obj.text = text;
            obj.updateText();
        };
        obj.setLeftListener = function (listener) {
            obj.leftListener = listener;
        };
        obj.setRightListener = function (listener) {
            obj.rightListener = listener;
        };
        obj.setLRText = function () {
            if(arguments[0]){
                obj.leftEl.innerText = arguments[0];
            }
            if(arguments[1]){
                obj.rightEl.innerText = arguments[1];
            }
        };
        obj.update();
        return obj;
    }
};

//应用相关的公共函数
window.appFun = {

    loadMoreCallback: 0,

    exitLogin: function () {
        window.Common.clearCookie("uid");
        window.Common.clearCookie("token");
    },
    getUID: function () {
        return window.Common.getCookie("uid");
    },
    getToken: function () {
        return window.Common.getCookie("token");
    },

    /**
     *  是否弹出过身份认证提示
     * @returns {boolean}
     */
    getIdentityHint: function () {
        return Common.getCookie("identity_hint") ? true : false;
    },
    /**
     * 保存身份认证提示
     */
    saveIdeIdentityHint: function () {
        Common.setCookie("identity_hint", "123");
    },
    /**
     * 保存开始日期
     * @param {Date} date
     */
    saveStartDate: function (date) {
        $.session.set("startDate", date.format("yyyy/MM/dd HH:mm:ss"));
    },
    /**
     * 保存结束日期
     * @param date
     */
    saveEndDate: function (date) {
        $.session.set("endDate", date.format("yyyy/MM/dd HH:mm:ss"));
    },
    /**
     *  返回开始日期；yyyy/MM/dd HH:mm:ss 格式的日期
     * @returns {string}
     */
    getStartDate: function () {
        return $.session.get("startDate");
    },
    /**
     * 返回结束日期
     * @returns {string}
     */
    getEndDate: function () {
        return $.session.get("endDate");
    },

    /**
     * 获取入住日期
     * @returns {{startDate: Date, endDate: Date}}
     */
    getDateObj: function () {
        var s = $.session.get("startDate");
        var e = $.session.get("endDate");
        var today = new Date().setTimeZero();
        if (s && e) {
            return {startDate: new Date(s), endDate: new Date(e)};
        }
        var ss = today.format("yyyy/MM/dd HH:mm:ss");
        var se = today.format("yyyy/MM/dd HH:mm:ss", 1);
        return {startDate: new Date(ss), endDate: new Date(se)};
    },


    /**
     *  返回上一页，如果上页不存在，则返回首页
     */
    back: function () {
        // if (history.length == 1 || window.Common.isEmpty(document.referrer)) {
        //     window.location.href = "el/h5/index.html";
        //     console.log(window.location);
        // } else {
        //     console.log(document.referrer);
        history.back();
        // window.location.href = document.referrer;
        // }
    },
    //增加收藏
    addCollect: function (url, func, hotel_id, callback) {
        if (this.isLogin()) {
            var send = {
                uid: this.getUID(),
                token: this.getToken(),
                product_id: hotel_id,
                like_type: 1,
            };
            func.ajaxPost(url, send, true, function (data) {
                if (data.success_complete == "1") {
                    Widget.toast("收藏成功");
                    if(typeof (callback) == "function"){
                        callback();
                    }
                } else {
                    Widget.toast("收藏失败");
                }
            }, function (data) {
                this.errorHandling(data, true);
            })
        } else {
            Widget.toast("没有登录不能进行收藏");
        }

    },

    /**
     * 判断是否登录
     * @returns {boolean} true.已登录<p>false.未登录
     */
    isLogin: function () {
        var uid = Common.getCookie("uid");
        var token = Common.getCookie("token");
        if (Common.isEmpty(uid) || Common.isEmpty(token)) {
            return false;
        }
        return true;
    },
    /**
     * 必须登录才能跳转的URL
     * @param url
     */
    loginUrl: function (url) {
        if (this.isLogin()) {
            window.location.href = url;
        } else if (!arguments[1]) {
            window.Widget.toast("您未登录，请先去登录");
        } else {
            window.sessionStorage.setItem("login_next_url", url);
            window.location.href = ROOT_PATH + "/dd/login/index.html";
        }
    },


    /**
     * 获取图片地址
     * @param {string}url 图片URL
     * @return {string} 返回加上域名后的URL
     */
    getImgUrl: function (url) {
        // return "http://162o24592p.51mypc.cn/el/upload/" + url;
        return "http://192.168.1.200/el/upload/" + url;
    },

    /**
     *  APP错误处理
     * @param data
     */
    errorHandling: function (data) {
        if (!data) {
            console.log("data参数不能为空");
            return;
        }
        if (data.error == 105 || data.error == 107) {
            Common.clearCookie("uid");
            Common.clearCookie("token");
            if (!arguments[1]) {
                window.location.href = ROOT_PATH + "/dd/login/index.html";
            } else {
                Widget.toast(data.error_msg);
            }
        } else {
            console.log("error_code:" + data.error);
            Widget.toast(data.error_msg);
        }
    },
    /**
     *     登录和未登录都能请求的API的错误处理,如果发生错误账号错误将调用回调函数
     * 否则弹出错误信息
     * @param {Object}data 服务器返回的错误
     * @param {function}callback  错误之后的回调函数,只有发生账号错误时才会发生
     */
    commonViewError : function (data, callback) {
        if(!data){
            console.log("data参数不能为空");
            return;
        }
        if(data.error == 105 || data.error == 107){
            Common.clearCookie("uid");
            Common.clearCookie("token");
            callback();
        } else {
            this.errorHandling(data);
        }
    },

    /**
     * 设置默认位置在长沙
     */
    setInitAddress: function () {
        $.session.set('lng', "112.882359");
        $.session.set('lat', "28.233967");
        $.session.set('province', "湖南省");
        $.session.set('city', "长沙市");
        $.session.set("district", "岳麓区");
        $.session.set("street", "岳麓大道");
        $.session.set("streetNumber", "580");
    },

    /**
     * 返回地址对象
     */
    getAddress : function () {
        try{
            return JSON.parse(window.sessionStorage.getItem("address"));
        } catch (e){
            return null;
        }
    },

    /**
     * 设置地址
     * 错误码
     * 1（检索词有岐义）
     * 2（检索地址有岐义）
     * 3（没有找到检索结果）
     * 4（key错误）
     * 5（网络连接错误）
     * 6（网络连接超时）
     * 7（还未完成鉴权，请在鉴权通过后重试）
     * @param {bMap}map bMap对象
     * @param {string}cityName 城市名字
     * @param {function(object)}success   设置成功
     * @param {function(object)}error     设置失败
     */
    setAddress : function (map, cityName, success, error) {
        map.getCoordsFromName({
            address:cityName
        }, function (ret, err) {
            if(ret.status){
                //把经纬转换成地址
                map.getNameFromCoords({
                    lon: ret.lon,
                    lat: ret.lat
                }, function (ret, err) {
                    if (ret.status) {
                        delete ret.status;
                        delete ret.poiList;
                        ret.address = ret.city;
                        window.sessionStorage.setItem("address", JSON.stringify(ret));
                        success(ret);
                    } else {
                        error(err);
                    }
                });
            } else {
                error(err);
            }
        });
    },

    /**
     * 定位
     * @param {bMap}map  bMap模块对象
     * @param {function(Object)}callback  定位成功回调
     */
    location : function (map, callback) {
        //定位失败
        var fail = function () {
            var addr = {
                lon : 112.882359,
                lat : 28.233967,
                address : "湖南省长沙市岳麓区岳麓大道辅道", //详细地址信息
                province : "湖南省",
                city : "长沙市",
                district : "岳麓区",
                streetName : "岳麓大道辅道",
                streetNumber : ""
            };
            window.sessionStorage.setItem("address", JSON.stringify(addr));
            if(callback){
                callback(addr);
            }
        };
        //把经纬转换成地址
        var coordsFromName = function (ret) {
            map.getNameFromCoords({
                lon: ret.lon,
                lat: ret.lat
            }, function(ret, err) {
                if (ret.status) {
                    delete ret.status;
                    delete ret.poiList;
                    window.sessionStorage.setItem("address", JSON.stringify(ret));
                    if(callback){
                        callback(ret);
                    }
                } else {
                    fail();
                }
            });
        };
        //定位获取经纬度
        map.getLocation({
            accuracy: '100m',
            autoStop: true,
            filter: 1
        }, function(ret, err) {
            if (ret.status) {
                coordsFromName(ret);
            } else {
                fail();
            }
        });
    },
    /**
     * 判断对象是否为空
     * @param {Object}obj
     * @return {boolean} true为空
     */
    isEmptyObj: function (obj) {
        for (var k in obj) {
            return false;
        }
        return true;
    },
    /**
     * 设置没有数据的图片提示
     * @param el 图片元素
     */
    noInfoImagePostion: function (el) {
        var w = el.clientWidth;
        var h = el.clientHeight;
        el.style.top = (window.innerHeight - h) / 2 + "px";
        el.style.left = (window.innerWidth - w) / 2 + "px";
    }
};